@@ -8,7 +8,7 @@ from .model import Dictionary, Scalar, List, Unknown, Tuple
 
 def _format_attrs(var):
     return (u'label={0.label}, required={0.required}, '
-            u'constant={0.constant}, linenos={0.linenos}, '
+            u'constant={0.constant}, linenos={0.linenos}, may_be_d={0.may_be_defined}, '
             u'c_as_u={0.checked_as_undefined}, c_as_d={0.checked_as_defined}').format(var).encode('utf-8')
 
 
